from .pychance_class import PyChance
from .data import SimpleTable
